import react, { useMemo, useEffect } from 'react';
import { useDispatch } from 'react-redux';
import { mapActions } from '../../store/map';
import _ from 'lodash';

import Layer from '../slippy/layer';
import Slippy from '../slippy/slippy';
import TiledMap from './tiled-map';
import GetLocation from './get-location';
import Whiteboard from './whiteboard';
import CurrentLocation from './current-location';
import {
  IonApp,
  IonButtons,
  IonContent,
  IonFooter,
  IonToolbar,
} from '@ionic/react';

const Map: react.FC<{}> = (props: {}) => {
  const dispatch = useDispatch();

  const resizeHandler = () => {
    dispatch(mapActions.resize());
  };
  const debouncedResizeHandler = useMemo(
    () => _.debounce(resizeHandler, 500),
    []
  );

  useEffect(() => {
    window.addEventListener('resize', debouncedResizeHandler);
    //    dispatch(mapActions.shift({ x: -50, y: 0 }));
  }, []);

  return (
    <>
      <IonContent fullscreen={true}>
        <IonApp>
          <Slippy>
            <Whiteboard>
              <CurrentLocation />
            </Whiteboard>
          </Slippy>
          <Layer>
            <TiledMap />
          </Layer>
        </IonApp>
      </IonContent>
      <IonFooter className='ion-no-border'>
        <IonToolbar>
          <IonButtons>
            <GetLocation />
          </IonButtons>
        </IonToolbar>
      </IonFooter>
    </>
  );
};

export default Map;
